#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gitit
version:              0.16
visibility:           public
id:                   gitit-0.16-IOuxd4UIx7tDyM6Way4Iey
key:                  gitit-0.16-IOuxd4UIx7tDyM6Way4Iey
license:              LicenseRef-GPL
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
stability:            experimental
synopsis:             Wiki using happstack, git or darcs, and pandoc.
description:
    Gitit is a wiki backed by a git, darcs, or mercurial
    filestore.  Pages and uploaded files can be modified either
    directly via the VCS'\''s command-line tools or through
    the wiki'\''s web interface. Pandoc is used for markup
    processing, so pages may be written in
    (extended) markdown, reStructuredText, LaTeX, HTML,
    or literate Haskell.

    Notable features include

    * plugins: dynamically loaded page
    transformations written in Haskell (see
    "Network.Gitit.Interface")

    * conversion of TeX math to MathML for display in
    web browsers

    * syntax highlighting of source code
    files and code snippets

    * Atom feeds (site-wide and per-page)

    * a library, "Network.Gitit", that makes it simple
    to include a gitit wiki in any happstack application

    For usage information:  @gitit --help@

category:             Network
abi:                  5090a54808baf4657c2853a04dc57e66
exposed:              True
exposed-modules:
    Network.Gitit Network.Gitit.Authentication
    Network.Gitit.Authentication.Github Network.Gitit.Cache
    Network.Gitit.Compat.Except Network.Gitit.Config
    Network.Gitit.ContentTransformer Network.Gitit.Feed
    Network.Gitit.Framework Network.Gitit.Handlers
    Network.Gitit.Initialize Network.Gitit.Interface
    Network.Gitit.Layout Network.Gitit.Page Network.Gitit.Plugins
    Network.Gitit.Server Network.Gitit.State Network.Gitit.Types
    Network.Gitit.Util Paths_gitit

import-dirs:          /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs:         /usr/lib/ghc-9.6.6/site-local/gitit-0.16
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/gitit-0.16
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/gitit
hs-libraries:         HSgitit-0.16-IOuxd4UIx7tDyM6Way4Iey
depends:
    HStringTemplate-0.8.8-6W4kb8rEptjRfJr67myqD
    HTTP-4000.5.0-BeXoSlmNNQg57gER4Z5fG5
    SHA-1.6.4.4-KRZJCS52poaHfqPlW5b8Sg
    aeson-2.2.2.0-DD8qksC39c7IadfiHLVY3V base-4.18.2.1
    base64-bytestring-1.2.1.0-LOSDeSQSndy1Y93aTSzs7h
    blaze-html-0.9.2.0-75IodrcvTCz887zmB9GdF1 bytestring-0.11.5.3
    containers-0.6.7 directory-1.3.8.5
    doctemplates-0.11.0.1-C5VwF0zo4dS7oX4KSL7d5a
    feed-1.3.2.1-DsTOE5ihMkC1Fvglft8J filepath-1.4.300.1
    filestore-0.6.5.1-H4qVUFMKw6aC6LrnqJEJAb ghc-9.6.6
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    happstack-server-7.9.3-8QqZiKByRPfBEcC0Rewd2L
    hoauth2-2.14.0-C3YCvHOFLnQIfcZJoc9oVI
    hslogger-1.3.2.0-5J7cXR4zP7qIvFH1YUzyfL
    http-client-tls-0.3.6.4-K9pa9aqIB7M16aJexgoa6z
    http-conduit-2.3.9.1-KDnV8VsG74SBT5pJfJbgZK
    json-0.11-Dk8HRpib8IrEFejxXondjx mtl-2.3.1
    network-3.1.4.0-4Rsy3d52Nm21mbavP5v2o
    network-bsd-2.8.1.0-5jWyJQYzAT48Le8IwU4Mfy
    network-uri-2.6.4.2-1CJs0qlSGKv7cmTNxU9YR0
    old-locale-1.0.0.7-Gunit3UBy5P9OGDVFY5MhC
    old-time-1.1.1.0-9WWjmNUa02UkaP5dbkbXm
    pandoc-3.10.2-8WUopLwiY76CAmtFiJjSvf
    pandoc-types-1.23.1.2-9jgLsuZngFN3JhSzLXhKOt parsec-3.1.16.1
    pretty-1.1.3.6 process-1.6.19.0
    random-1.2.1.3-JQ5HMleih0QHEX58PgSIMQ
    recaptcha-0.1.0.4-9lMvRgLScO1Kq8QcK8e9ER
    safe-0.3.21-Bi0eBD0gemq14I72arTwzC
    skylighting-0.14.7-2pl4xo32zySLDeRK1DtzfO
    split-0.2.5.1-FQ4kT9wgw7JDP8h2QeY4XG
    syb-0.7.4-BzNZTTWYfk9HN4YOl0udkE
    tagsoup-0.14.8-Jofx75aM8f9HSzIPhK6jac
    temporary-1.3-1ezn4dc6wi13jwuWHEP4w4 text-2.0.2 time-1.12.2
    uri-bytestring-0.3.3.1-6tTjyarEottE4mZ6OoWOPR
    url-2.1.3-FnoMg0Amz5x5iDNEWuwHDq
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv
    uuid-1.3.16.1-7PYZMZ1xYXRJIRW62n80Y6 xhtml-3000.2.2.1
    xml-1.3.14-3CsuYrgQlhu1X5fBOwcswt
    xml-conduit-1.9.1.4-8KUCyd3gacoDIkKnNcSOki
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau
    xss-sanitize-0.3.7.2-C6JezetFpwW6Kah9FICVTV
    zlib-0.7.1.1-D2e2i4PjHPPGlB4wotxVYg

haddock-interfaces:   /usr/share/doc/gitit/html/gitit.haddock
haddock-html:         /usr/share/doc/gitit/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

